@@ -3,29 +3,30 @@
 library(sunburstR)
 
 # read in sample visit-sequences.csv data provided in source
+# only use first 200 rows to speed package build and check
 #   https://gist.github.com/kerryrodden/7090426#file-visit-sequences-csv
 sequences <- read.csv(
   system.file("examples/visit-sequences.csv",package="sunburstR")
   ,header = FALSE
   ,stringsAsFactors = FALSE
-)
+)[1:100,]
 
 sunburst(sequences)
 
+\dontrun{
+
 # explore some of the arguments
 sunburst(
   sequences
   ,count = TRUE
 )
 
-\dontrun{
-
 sunburst(
   sequences
-  # apply sort order to the legendS
+  # apply sort order to the legends
   ,legendOrder = unique(unlist(strsplit(sequences[,1],"-")))
   # just provide the name in the explanation in the center
-  ,explanation = "function(d){return d.name}"
+  ,explanation = "function(d){return d.data.name}"
 )
 
 
@@ -34,7 +35,7 @@ sequence_json <- jsonlite::fromJSON(
   system.file("examples/visit-sequences.json",package="sunburstR"),
   simplifyDataFrame = FALSE
 )
-sunburst(jsondata = sequence_json)
+sunburst(sequence_json)
 
 
 
@@ -48,7 +49,7 @@ sunburst(
       "7515402/raw/9f80d28094dc9dfed7090f8fb3376ef1539f4fd2/",
       "comment-sequences.csv"
     )
-    ,header = FALSE
+    ,header = TRUE
     ,stringsAsFactors = FALSE
   )
 )
